Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Bootstrapper ¶
type Bootstrapper interface {
// Client setups up any client connections to remote provider
Client() error
// Prepare setups up any needed infrastructure
Prepare() error
// Provision runs the management cluster creation steps
Provision() error
// Progress watches the cluster creation for progress
Progress() error
// Finalize saves any deliverables and removes any created bootstrap infrastructure
Finalize() error
// Events are status messages from the implementation
Events() progress.Events
}
Bootstrapper is the interface for creating infrastructure to run a cake engine against
type Spec ¶
type Spec struct {
cluster.K8sConfig `yaml:",inline" json:",inline" mapstructure:",squash"`
EventStream progress.Events `yaml:"-" json:"-" mapstructure:"-"`
EngineType types.EngineType `yaml:"EngineType" json:"enginetype"`
LogFile string `yaml:"LogFile" json:"logfile"`
SSH cluster.SSH `yaml:"SSH" json:"ssh"`
BootstrapperIP string `yaml:"-" json:"-" mapstructure:"-"`
}
Spec for the Provider
Click to show internal directories.
Click to hide internal directories.