Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetMetadata ¶
func GetMetadata(metadataValues *MetadataValues) ([]byte, error)
GetMetadata returns the metadata
func GetUserData ¶
func GetUserData(values *UserDataValues) ([]byte, error)
GetUserData returns the user data
Types ¶
type Config ¶
type Config []types.BaseOptionValue
Config for base options
func GenerateUserData ¶
GenerateUserData creates the user data
func (*Config) SetCloudInitMetadata ¶
SetCloudInitMetadata sets the cloud init user data at the key "guestinfo.metadata" as a base64-encoded string.
func (*Config) SetCloudInitUserData ¶
SetCloudInitUserData sets the cloud init user data at the key "guestinfo.userdata" as a base64-encoded string.
type MetadataValues ¶
type MetadataValues struct {
Hostname string
Networks []NetworkConfig
}
MetadataValues used
type NetworkConfig ¶
type NetworkConfig struct {
MACAddress string
DHCP4 bool
IPAddress string
Netmask string
Gateway string
NameServers []string
DNSSearch []string
}
NetworkConfig values
type UserDataValues ¶
UserDataValues for system
Click to show internal directories.
Click to hide internal directories.